# mekara

> I dream of roombas - thousands of automated AI robots that autonomously maintain codebases\
> — [_Geoffrey Huntley_](https://ghuntley.com/ktlo/)

`mekara` (មករា -- Khmer for January, the start of a brand new cycle of AI-centric software engineering) is **Workflows as Code**: like [IaC](https://en.wikipedia.org/wiki/Infrastructure_as_code) but for your development processes. It mechanizes your codebase by systematically automating your existing manual workflows. You be you, if you were _fast_ like AI and consistent like code.

See more at the **[official docs](https://meksys-dev.github.io/mekara/)**, the single source of truth for this project.

## Getting Started

### For Humans

See the [development quickstart](https://meksys-dev.github.io/mekara/docs/development/quickstart/for-humans) for installation and setup instructions.

### For AI Assistants

See the [AI development guide](https://meksys-dev.github.io/mekara/docs/development/quickstart/for-ais) for codebase conventions and contribution guidelines.
